==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/request/AppleUserInitiatedEnrollmentProfileRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.util.Map;

import odata.msgraph.client.beta.entity.AppleUserInitiatedEnrollmentProfile;
import odata.msgraph.client.beta.entity.collection.request.AppleEnrollmentProfileAssignmentCollectionRequest;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonIgnoreType
public class AppleUserInitiatedEnrollmentProfileRequest extends EntityRequest<AppleUserInitiatedEnrollmentProfile> {

    public AppleUserInitiatedEnrollmentProfileRequest(ContextPath contextPath) {
        super(AppleUserInitiatedEnrollmentProfile.class, contextPath, SchemaInfo.INSTANCE);
    }

    public AppleEnrollmentProfileAssignmentCollectionRequest assignments() {
        return new AppleEnrollmentProfileAssignmentCollectionRequest(
                        contextPath.addSegment("assignments"));
    }

    public AppleEnrollmentProfileAssignmentRequest assignments(String id) {
        return new AppleEnrollmentProfileAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id.toString())));
    }

    @Action(name = "setPriority")
    @JsonIgnore
    public ActionRequestNoReturn setPriority(Integer priority) {
        Preconditions.checkNotNull(priority, "priority cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("priority", "Edm.Int32", priority)
            .build();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.setPriority"), _parameters);
    }

}

==> odata-client-msgraph-beta-0.2.2-sources.jar: odata/msgraph/client/beta/entity/request/AppleUserInitiatedEnrollmentProfileRequest.java <==
package odata.msgraph.client.beta.entity.request;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonIgnoreType;
import com.github.davidmoten.guavamini.Preconditions;
import com.github.davidmoten.odata.client.ActionRequestNoReturn;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.EntityRequest;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.annotation.Action;
import com.github.davidmoten.odata.client.internal.ParameterMap;
import com.github.davidmoten.odata.client.internal.TypedObject;

import java.lang.Integer;
import java.lang.Object;
import java.lang.String;
import java.util.Map;
import java.util.Optional;

import odata.msgraph.client.beta.entity.AppleUserInitiatedEnrollmentProfile;
import odata.msgraph.client.beta.entity.collection.request.AppleEnrollmentProfileAssignmentCollectionRequest;

@JsonIgnoreType
public class AppleUserInitiatedEnrollmentProfileRequest extends EntityRequest<AppleUserInitiatedEnrollmentProfile> {

    public AppleUserInitiatedEnrollmentProfileRequest(ContextPath contextPath, Optional<Object> value) {
        super(AppleUserInitiatedEnrollmentProfile.class, contextPath, value, false);
    }

    public AppleEnrollmentProfileAssignmentRequest assignments(String id) {
        return new AppleEnrollmentProfileAssignmentRequest(contextPath.addSegment("assignments").addKeys(new NameValue(id, String.class)), Optional.empty());
    }

    public AppleEnrollmentProfileAssignmentCollectionRequest assignments() {
        return new AppleEnrollmentProfileAssignmentCollectionRequest(
                        contextPath.addSegment("assignments"), Optional.empty());
    }

    @Action(name = "setPriority")
    @JsonIgnore
    public ActionRequestNoReturn setPriority(Integer priority) {
        Preconditions.checkNotNull(priority, "priority cannot be null");
        Map<String, TypedObject> _parameters = ParameterMap
            .put("priority", "Edm.Int32", priority)
            .build();
        return new ActionRequestNoReturn(this.contextPath.addActionOrFunctionSegment("microsoft.graph.setPriority"), _parameters);
    }

}
